Copyright (C) 2014-2018 H. Turgut Uyar <uyar@tekir.org>

Piculet is a module for extracting data from XML or HTML documents
using XPath queries. It consists of a `single source file`_
with no dependencies other than the standard library, which makes it very easy
to integrate into applications. It also provides a command line interface.

:PyPI: https://pypi.python.org/pypi/piculet/
:Repository: https://bitbucket.org/uyar/piculet
:Documentation: https://piculet.readthedocs.io/

Piculet has been tested with Python 2.7, Python 3.4+, PyPy2 5.7+,
and PyPy3 5.7+. You can install the latest version using ``pip``::

    pip install piculet

.. _single source file: https://bitbucket.org/uyar/piculet/src/tip/piculet.py
